# -*- coding: utf-8 -*-
import graphene

from graphene import AbstractType

from pages.models.slider import Slider
from pages.api.slider.schema.nodes.slider import SliderNode


class SliderQuery(AbstractType):
    slider = graphene.Field(SliderNode, id=graphene.Int(), slug=graphene.String())
    sliders = graphene.List(SliderNode, description='List of sliders')

    def resolve_sliders(self, args, context, inf):
        return Slider.objects.activated()

    def resolve_slider(self, args, context, inf):
        page = Slider.objects.none()
        if args.get('id', None):
            return Slider.objects.activated().get(id=args.get('id', None))
        elif args.get('slug', None):
            page = Slider.objects.activated().get(slug=args.get('slug', None))
        return page



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0003_auto_20170607_0959'),
    ]

    operations = [
        migrations.CreateModel(
            name='Product',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('modified', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('reference_id', models.CharField(max_length=20)),
                ('page', models.ForeignKey(to='pages.Page')),
            ],
            options={
                'db_table': 'products',
            },
            bases=(models.Model,),
        ),
    ]



# -*- coding: utf-8 -*-
import graphene
import json

from graphene_django import DjangoObjectType
from graphene.types.json import JSONString

from pages.models.slider import Slider, SliderItem, \
    SliderContentType, SliderContent


class SliderContentNode(DjangoObjectType):

    config = JSONString()

    class Meta:
        model = SliderContent

    def resolve_config(self, args, context, info):
        return json.loads(self.config)


class SliderContentTypeNode(DjangoObjectType):

    class Meta:
        model = SliderContentType


class SliderItemNode(DjangoObjectType):

    contents = graphene.List(SliderContentNode)

    absolute_url_picture_pc = graphene.String()

    absolute_url_picture_tablet = graphene.String()

    absolute_url_picture_mobile = graphene.String()

    class Meta:
        model = SliderItem

    def resolve_contents(self, args, request, info):
        return self.slidercontent_set.all().order_by('order')

    def resolve_absolute_url_picture_pc(self, args, request, info):
        return self.absolute_url_picture_pc

    def resolve_absolute_url_picture_tablet(self, args, request, info):
        return self.absolute_url_picture_tablet

    def resolve_absolute_url_picture_mobile(self, args, request, info):
        return self.absolute_url_picture_mobile


class SliderNode(DjangoObjectType):

    items = graphene.List(SliderItemNode)

    class Meta:
        model = Slider

    def resolve_items(self, args, request, info):
        return self.slideritem_set.all().order_by('order')




# -*- coding: utf-8 -*-
import graphene
from graphene_django import DjangoObjectType

from pages.models.page import PageTimer
from pages.api.slider.schema.nodes.slider import SliderNode


class TimerNode(DjangoObjectType):

    class Meta:
        model = PageTimer



import graphene

from graphene_django.debug import DjangoDebug

from pages.api.page.schema.queries.page import PageQuery
from pages.api.slider.schema.queries.slider import SliderQuery


class Query(PageQuery, SliderQuery, graphene.ObjectType):
    debug = graphene.Field(DjangoDebug, name='__debug')

schema = graphene.Schema(query=Query, auto_camelcase=False)


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0004_product'),
    ]

    operations = [
        migrations.CreateModel(
            name='PageTag',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('seo_title', models.CharField(max_length=100)),
                ('seo_sub_title', models.CharField(max_length=100)),
                ('seo_desc', models.CharField(max_length=100)),
                ('seo_keywords', models.CharField(max_length=100)),
                ('created', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('modified', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('is_active', models.BooleanField(default=False)),
                ('title', models.CharField(max_length=200)),
                ('slug', models.SlugField(max_length=230)),
                ('page', models.ForeignKey(to='pages.Page')),
            ],
            options={
                'abstract': False,
            },
            bases=(models.Model,),
        ),
        migrations.AlterField(
            model_name='page',
            name='slug',
            field=models.SlugField(max_length=230),
            preserve_default=True,
        ),
        migrations.AlterField(
            model_name='page',
            name='title',
            field=models.CharField(max_length=200),
            preserve_default=True,
        ),
        migrations.AlterField(
            model_name='product',
            name='reference_id',
            field=models.CharField(unique=True, max_length=20),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0012_auto_20170616_0232'),
    ]

    operations = [
        migrations.AlterField(
            model_name='product',
            name='reference_id',
            field=models.CharField(max_length=40),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='product',
            unique_together=set([('page', 'reference_id')]),
        ),
    ]



# -*- coding: utf-8 -*-
from django.db import models
from pages.utils.database import AuditableMixin


class Product(AuditableMixin):
    page = models.ForeignKey('Page')
    reference_id = models.CharField(max_length=40)

    def __str__(self):
        return self.reference_id

    class Meta:
        db_table = 'products'
        unique_together = ('page', 'reference_id')



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.test import TestCase

from pages.schema import schema
from pages.utils import admin
from pages.models.page import Page


class PageTestCase(TestCase):

    def setUp(self):
        self.page = self._create_page()

    def _create_page(self):
        page = Page()
        page.title = 'Test Page'
        page.external_url = 'https://www.crehana.com/'
        page.is_active = True
        page.save()
        return page

    def get_pages_query(self):
        query = '''
                    {
                       pages {
                         title
                         slug
                         external_url
                         is_active
                       }
                     }
                '''
        return query

    def get_page_query(self):
        query = '''
                    {
                       page(id: %s) {
                         title
                         slug
                         external_url
                         is_active
                       }
                     }
                ''' % self.page.id
        return query

    def test_get_pages(self):
        result = schema.execute(self.get_pages_query())
        pages = result.data.get('pages', [])
        self.assertEquals(len(pages), 1)

    def test_get_page(self):
        result = schema.execute(self.get_page_query())
        page = result.data.get('page', {})
        self.assertEquals(page.get('title'), 'Test Page')

    def test_autogenerate_slug(self):
        self.assertEquals(self.page.slug, 'test-page')
        page = Page()
        page.title = 'Test Page'
        page.external_url = 'https://www.crehana.com/'
        page.is_active = True
        page.save()
        self.assertEquals(page.slug, 'test-page-1')
        page = Page()
        page.title = 'Test Page'
        page.external_url = 'https://www.crehana.com/'
        page.is_active = True
        page.save()
        self.assertEquals(page.slug, 'test-page-2')
